TcpStream

Struct TcpStream 

pub struct TcpStream { /* private fields */ }
A goroutine-aware TCP stream socket.

read and write park the goroutine when the operation would block and resume it when data is available or the send buffer has space.

Implementations

Source

impl TcpStream

pub fn connect<A: ToSocketAddrs>(addr: A) -> Result<Self>

Connect to addr.

Parks the goroutine until the connection completes if it does not complete immediately (which is typical for non-blocking connect).

Equivalent to net.Dial("tcp", addr) in Go.

pub fn read(&mut self, buf: &mut [u8]) -> Result<usize>

Read bytes from the stream into buf.

Parks the goroutine if no data is immediately available.

pub fn write(&mut self, buf: &[u8]) -> Result<usize>

Write buf to the stream.

Parks the goroutine if the send buffer is full. Returns the number of bytes written (may be less than buf.len()).

pub fn as_raw_fd(&self) -> RawFd

Return the underlying raw file descriptor.