pub struct TcpListener { /* private fields */ }Expand description
A goroutine-aware TCP server socket.
Calls to accept park the current goroutine when no
connection is immediately available and resume it when one arrives.
Implementations
Sourceimpl TcpListener
impl TcpListener
Sourcepub fn bind<A: ToSocketAddrs>(addr: A) -> Result<Self>
pub fn bind<A: ToSocketAddrs>(addr: A) -> Result<Self>
Bind a non-blocking TCP listener to addr.
Equivalent to net.Listen("tcp", addr) in Go.