pub struct TcpStream { /* private fields */ }Expand description
Implementations
Sourceimpl TcpStream
impl TcpStream
Sourcepub fn connect<A: ToSocketAddrs>(addr: A) -> Result<Self>
pub fn connect<A: ToSocketAddrs>(addr: A) -> Result<Self>
Connect to addr.
Parks the goroutine until the connection completes if it does not
complete immediately (which is typical for non-blocking connect).
Equivalent to net.Dial("tcp", addr) in Go.
Sourcepub fn read(&mut self, buf: &mut [u8]) -> Result<usize>
pub fn read(&mut self, buf: &mut [u8]) -> Result<usize>
Read bytes from the stream into buf.
Parks the goroutine if no data is immediately available.